@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002 2003 2004 2005, Magnus Hjorth
+ * Copyright (C) 2002 2003 2004 2005 2008 2009 2010 2011 2012, Magnus Hjorth
  *
  * This file is part of mhWaveEdit.
  *
@@ -22,6 +22,8 @@
 #include <config.h>
 #include <gdk/gdkkeysyms.h>
 
+#include <math.h>
+
 #include "sound.h"
 #include "inifile.h"
 #include "main.h"
@@ -32,6 +34,7 @@
 #include "player.h"
 #include "rateconv.h"
 #include "gettext.h"
+#include "filetypes.h"
 
 static GtkObjectClass *parent_class;
 
@@ -60,6 +63,7 @@ static void config_dialog_ok(GtkButton *button, gpointer user_data)
 	intbox_check(cd->view_quality) ||
 	intbox_check_limit(cd->recent_files,0,MAINWINDOW_RECENT_MAX,
 			   _("number of recent files")) ||
+        intbox_check_limit(cd->vzoom_max,1,9999, _("maximum vertical zoom")) ||
 	format_selector_check(cd->fallback_format))
         return;
     /* c = (gchar *)gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(cd->sound_driver)->entry)); */
@@ -87,6 +91,8 @@ static void config_dialog_ok(GtkButton *button, gpointer user_data)
 			 gtk_toggle_button_get_active(cd->hzoom_default));
     inifile_set_gboolean(INI_SETTING_SPEED,
 			 gtk_toggle_button_get_active(cd->speed_default));
+    inifile_set_gboolean(INI_SETTING_SLABELS,
+			 gtk_toggle_button_get_active(cd->labels_default));
     inifile_set(INI_SETTING_MIXER,
 		(char *)gtk_entry_get_text(cd->mixer_utility));
     inifile_set_gboolean("useGeometry",
@@ -137,6 +143,8 @@ static void config_dialog_ok(GtkButton *button, gpointer user_data)
 
     inifile_set_guint32("recentFiles",cd->recent_files->val);
 
+    inifile_set_guint32("vzoomMax",cd->vzoom_max->val);
+
     format_selector_get(cd->fallback_format,&player_fallback_format);
     format_selector_save_to_inifile(cd->fallback_format,"playerFallback");
 
@@ -161,11 +169,20 @@ static void config_dialog_ok(GtkButton *button, gpointer user_data)
 
     dither_editing = gtk_toggle_button_get_active(cd->dither_editing);
     inifile_set_guint32("ditherEditing",
-			dither_editing?DITHER_TRIANGULAR:DITHER_NONE);
+			dither_editing?DITHER_MINIMAL:DITHER_NONE);
     dither_playback = gtk_toggle_button_get_active(cd->dither_playback);
     inifile_set_guint32("ditherPlayback",
-			dither_playback?DITHER_TRIANGULAR:DITHER_NONE);
+			dither_playback?DITHER_MINIMAL:DITHER_NONE);
+
+    if (sndfile_ogg_supported())
+	 inifile_set_guint32("sndfileOggMode",
+			     combo_selected_index(cd->oggmode));
+
+    sample_convert_mode = combo_selected_index(cd->convmode);
+    inifile_set_guint32("sampleMode",sample_convert_mode);
+
     gtk_widget_destroy(GTK_WIDGET(cd));
+
     mainwindow_update_texts();
 }
 
@@ -555,6 +572,16 @@ static void config_dialog_init(ConfigDialog *cd)
 				      INI_SETTING_SPEED, 
 				      INI_SETTING_SPEED_DEFAULT));
 
+    w = gtk_check_button_new_with_label("");
+    key = gtk_label_parse_uline(GTK_LABEL (GTK_BIN (w)->child),
+				_("Show slider l_abels by default"));
+    gtk_widget_add_accelerator (w, "clicked", ag, key, GDK_MOD1_MASK,
+				(GtkAccelFlags) 0);
+    cd->labels_default = GTK_TOGGLE_BUTTON(w);
+    gtk_toggle_button_set_active(cd->labels_default,
+				 inifile_get_gboolean(INI_SETTING_SLABELS,
+						      INI_SETTING_SLABELS_DEFAULT));
+
     w = gtk_button_new_with_label("");
     key = gtk_label_parse_uline(GTK_LABEL(GTK_BIN(w)->child), _("_Settings"));
     gtk_widget_add_accelerator(w, "clicked", ag, key, GDK_MOD1_MASK, 
@@ -740,6 +767,9 @@ static void config_dialog_init(ConfigDialog *cd)
 
     w = intbox_new(inifile_get_guint32("recentFiles",4));
     cd->recent_files = INTBOX(w);
+
+    w = intbox_new(inifile_get_guint32("vzoomMax",100));
+    cd->vzoom_max = INTBOX(w);
     
     w = gtk_check_button_new_with_label("");
     key = gtk_label_parse_uline(GTK_LABEL (GTK_BIN (w)->child), 
@@ -795,6 +825,27 @@ static void config_dialog_init(ConfigDialog *cd)
     gtk_signal_connect(GTK_OBJECT(w),"toggled",
 		       GTK_SIGNAL_FUNC(driver_autodetect_toggled),cd);
 
+    w = combo_new();
+    l = NULL;
+    l = g_list_append(l,_("Direct access"));
+    l = g_list_append(l,_("Decompress"));
+    l = g_list_append(l,_("Bypass"));
+    combo_set_items(COMBO(w),l,inifile_get_guint32("sndfileOggMode",1));
+    g_list_free(l);
+    if (!sndfile_ogg_supported()) {
+	 combo_set_selection(COMBO(w),2);
+	 gtk_widget_set_sensitive(w,FALSE);
+    }
+    cd->oggmode = COMBO(w);
+
+    w = combo_new();
+    l = NULL;
+    l = g_list_append(l,_("Biased"));
+    l = g_list_append(l,_("Pure-Scaled"));
+    combo_set_items(COMBO(w),l,sample_convert_mode);
+    g_list_free(l);
+    cd->convmode = COMBO(w);
+
     /* Layout the window */
     
     a = gtk_vbox_new(FALSE,5);
@@ -849,12 +900,20 @@ static void config_dialog_init(ConfigDialog *cd)
     gtk_container_add(GTK_CONTAINER(d),e);
     f = GTK_WIDGET(cd->time_scale_default);
     gtk_box_pack_start(GTK_BOX(e),f,FALSE,FALSE,0);
-    f = GTK_WIDGET(cd->hzoom_default);
-    gtk_box_pack_start(GTK_BOX(e),f,FALSE,FALSE,0);
     f = GTK_WIDGET(cd->vzoom_default);
     gtk_box_pack_start(GTK_BOX(e),f,FALSE,FALSE,0);
     f = GTK_WIDGET(cd->speed_default);
     gtk_box_pack_start(GTK_BOX(e),f,FALSE,FALSE,0);
+    f = GTK_WIDGET(cd->labels_default);
+    gtk_box_pack_start(GTK_BOX(e),f,FALSE,FALSE,0);
+    f = gtk_hbox_new(FALSE,3);
+    gtk_box_pack_start(GTK_BOX(e),f,FALSE,FALSE,0);
+    g = gtk_label_new(_("Vertical zoom limit: "));
+    gtk_box_pack_start(GTK_BOX(f),g,FALSE,FALSE,0);
+    g = GTK_WIDGET(cd->vzoom_max);
+    gtk_box_pack_start(GTK_BOX(f),g,FALSE,FALSE,8);
+    g = gtk_label_new(_("x"));
+    gtk_box_pack_start(GTK_BOX(f),g,FALSE,FALSE,0);
 
 
     c = gtk_vbox_new(FALSE,14);
@@ -972,8 +1031,17 @@ static void config_dialog_init(ConfigDialog *cd)
     gtk_box_pack_start(GTK_BOX(e),f,FALSE,FALSE,0);
     f = GTK_WIDGET(cd->floating_tempfiles);
     gtk_box_pack_start(GTK_BOX(e),f,FALSE,FALSE,0);
-
-
+    f = gtk_label_new(_("Some versions of libsndfile supports accessing "
+			"Ogg files without decompressing to a temporary "
+			"file."));
+    gtk_box_pack_start(GTK_BOX(e),f,FALSE,FALSE,0);
+    gtk_label_set_line_wrap(GTK_LABEL(f),TRUE);
+    f = gtk_hbox_new(FALSE,3);
+    gtk_box_pack_start(GTK_BOX(e),f,FALSE,FALSE,0);
+    g = gtk_label_new("Libsndfile ogg handling: ");
+    gtk_box_pack_start(GTK_BOX(f),g,FALSE,FALSE,0);
+    g = GTK_WIDGET(cd->oggmode);
+    gtk_box_pack_start(GTK_BOX(f),g,TRUE,TRUE,0);
 
     c = gtk_vbox_new(FALSE,14);
     gtk_container_set_border_width(GTK_CONTAINER(c),8);
@@ -1005,6 +1073,17 @@ static void config_dialog_init(ConfigDialog *cd)
     f = GTK_WIDGET(cd->dither_playback);
     gtk_box_pack_start(GTK_BOX(e),f,FALSE,FALSE,0);
 
+    d = gtk_frame_new(_(" Sample conversion "));
+    gtk_box_pack_start(GTK_BOX(c),d,FALSE,FALSE,0);
+    e = gtk_vbox_new(FALSE,3);
+    gtk_container_add(GTK_CONTAINER(d),e);
+    gtk_container_set_border_width(GTK_CONTAINER(e),5);
+    f = gtk_hbox_new(FALSE,0);
+    gtk_box_pack_start(GTK_BOX(e),f,FALSE,FALSE,0);
+    g = gtk_label_new(_("Normalization mode: "));
+    gtk_box_pack_start(GTK_BOX(f),g,FALSE,FALSE,0);
+    g = GTK_WIDGET(cd->convmode);
+    gtk_box_pack_start(GTK_BOX(f),g,TRUE,TRUE,0);
 
     c = gtk_vbox_new(FALSE,14);
     gtk_container_set_border_width(GTK_CONTAINER(c),8);
