@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002 2003 2004 2005, Magnus Hjorth
+ * Copyright (C) 2002 2003 2004 2005 2008 2009 2011 2012, Magnus Hjorth
  *
  * This file is part of mhWaveEdit.
  *
@@ -38,12 +38,13 @@ typedef struct {
      Intbox *sound_buffer_size;
      GtkEntry *mixer_utility;
      GtkToggleButton *time_scale_default,*sound_lock,*roll_cursor,*improve;
-     GtkToggleButton *vzoom_default, *hzoom_default,*speed_default;
+     GtkToggleButton *vzoom_default, *hzoom_default,*speed_default,*labels_default;
      GtkToggleButton *output_bswap,*center_cursor,*mark_autoplay;
      GtkToggleButton *mainwin_front,*varispeed_enable,*varispeed_autoreset;
      GtkToggleButton *varispeed_fast,*dither_editing,*dither_playback;
      GtkToggleButton *driver_autodetect,*output_stereo;
      Intbox *recent_files;
+     Intbox *vzoom_max;
      Intbox *view_quality;
      Combo *time_display,*time_display_timescale,*varispeed_method,
 	  *speed_method;
@@ -55,6 +56,8 @@ typedef struct {
      GtkEntry *tempdir_add_entry;
      FormatSelector *fallback_format;
      GtkToggleButton *floating_tempfiles;
+     Combo *oggmode;
+     Combo *convmode;
 } ConfigDialog;
 
 typedef struct {
