@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002 2003 2004 2005 2007, Magnus Hjorth
+ * Copyright (C) 2002 2003 2004 2005 2007 2008 2010 2011 2012, Magnus Hjorth
  *
  * This file is part of mhWaveEdit.
  *
@@ -29,6 +29,7 @@
 #include <errno.h>
 #include <locale.h>
 #include <signal.h>
+#include <ctype.h>
 #include <gtk/gtk.h>
 #include "mainloop.h"
 #include "mainwindow.h"
@@ -214,12 +215,15 @@ int main(int argc, char **argv)
 				 &player_fallback_format);
      chunk_filter_use_floating_tempfiles = 
 	  inifile_get_gboolean("tempfilesFP",TRUE);
-     dither_editing = inifile_get_guint32("ditherEditing",DITHER_TRIANGULAR);
+     dither_editing = inifile_get_guint32("ditherEditing",DITHER_MINIMAL);
      if (dither_editing < 0 || dither_editing > DITHER_MAX)
-	  dither_editing = DITHER_TRIANGULAR;
+	  dither_editing = DITHER_MINIMAL;
      dither_playback = inifile_get_gboolean("ditherPlayback",DITHER_NONE);
      if (dither_playback < 0 || dither_playback > DITHER_MAX)
 	  dither_playback = DITHER_NONE;
+     sample_convert_mode = inifile_get_guint32("sampleMode",CONVERT_MODE_NOOFFS);
+     if (sample_convert_mode < 0 || sample_convert_mode > CONVERT_MODE_MAX)
+	  sample_convert_mode = CONVERT_MODE_NOOFFS;
 
      gtk_hbutton_box_set_layout_default(GTK_BUTTONBOX_END);
 
@@ -431,11 +435,11 @@ static void parse_color(gchar *str, GdkColor *color)
 void set_custom_colors(GdkColor *c)
 {
      gint i;
-     gchar *d,*e;
+     gchar *d;
      if (!c) {
 	  set_custom_colors(factory_default_colors);
 	  for (i=FIRST_CUSTOM_COLOR; i<LAST_COLOR; i++) {
-	       e = d = inifile_get(color_inifile_entry[i],NULL);
+	       d = inifile_get(color_inifile_entry[i],NULL);
 	       /* printf("%s -> %s\n",color_inifile_entry[i],d); */
 	       if (d != NULL) {
 		    /* printf("Before: %x,%x,%x\n",color_table[i].red,
@@ -520,7 +524,7 @@ void byteswap(void *buffer, int element_size, int buffer_size)
      int i,j;
      char *c,*d,*bufend=NULL;
      char tempbuf[BYTESWAP_BSIZE];
-     g_assert(element_size < 7);
+     g_assert(element_size < 7 || element_size==8);
      if (element_size == 1) return;
      while (buffer_size != 0) {
 	  i = BYTESWAP_BSIZE;
@@ -584,7 +588,7 @@ gchar *get_time(guint32 samplerate, off_t samples, off_t samplemax,
 		gchar *timebuf, gint mode)
 {
      static gchar static_buf[64];
-     gfloat secs, ffps, fframes;
+     gfloat secs, ffps;
      guint mins, msecs, hours, maxhours, frames, ifps, isecs;
      guint fptm;
 
@@ -596,7 +600,7 @@ gchar *get_time(guint32 samplerate, off_t samples, off_t samplemax,
      if (mode > 6) mode = 0;
 
      if (mode == 2) {
-	  g_snprintf(timebuf,50,"%05" OFF_T_FORMAT,samples);
+	  g_snprintf(timebuf,50,"%05" OFF_T_FORMAT,(OFF_T_FTYPE)samples);
      } else if (mode < 2) {
 	  secs = (gfloat) samples / (gfloat) samplerate;
 	  mins = (guint) (secs / 60.0);
@@ -634,7 +638,6 @@ gchar *get_time(guint32 samplerate, off_t samples, off_t samplemax,
 	  else if (mode == 5) { ffps=30.0*1.000/1.001; ifps=30; }
 	  else { ffps=30.0; ifps=30; }
 
-	  fframes = secs * ffps;
 	  frames = (guint) (secs * ffps);
 
 	  /* Ten-minute units never need to be dropped. */
