@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2002 2003 2004 2005 2006, Magnus Hjorth
+ * Copyright (C) 2002 2003 2004 2005 2006 2007 2008 2009 2010, Magnus Hjorth
+ * Copyright (C) 2011 2012, Magnus Hjorth
  *
  * This file is part of mhWaveEdit.
  *
@@ -89,8 +90,10 @@ void gtk_widget_set_can_focus(GtkWidget *w, gboolean can_focus);
 
 #if SIZEOF_OFF_T > 4
 #define OFF_T_FORMAT "lld"
+#define OFF_T_FTYPE long long
 #else
 #define OFF_T_FORMAT "ld"
+#define OFF_T_FTYPE long
 #endif
 
 #define BOOLEQ(x,y) (((x) && (y)) || (!(x) && !(y)))
