@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2002 2003 2004 2005 2006 2007, Magnus Hjorth
+ * Copyright (C) 2002 2003 2004 2005 2006 2007 2008 2009 2010, Magnus Hjorth
+ * Copyright (C) 2011 2012, Magnus Hjorth
  *
  * This file is part of mhWaveEdit.
  *
@@ -201,27 +202,13 @@ static void fix_title(Mainwindow *wnd)
 {
      gchar *c;
      if (wnd->doc != NULL) {
-	  if (wnd->doc->chunk->format.type == DATAFORMAT_FLOAT)
-	       
-	       c = g_strdup_printf ( _("mhWaveEdit: %s (%s): %d Hz, "
-				     "%s"), 
-				     wnd->doc->titlename, 
-				     chunk_get_time(wnd->doc->chunk,
-						    wnd->doc->chunk->length,
-						    NULL),
-				     wnd->doc->chunk->format.samplerate,
-				     (wnd->doc->chunk->format.samplesize >
-				      sizeof(float))?_("double"):_("float"));
-	  else
-	       c = g_strdup_printf ( _("mhWaveEdit: %s (%s): %d Hz, "
-				     "%d bit"), 
-				     wnd->doc->titlename, 
-				     chunk_get_time(wnd->doc->chunk,
-						    wnd->doc->chunk->length,
-						    NULL),
-				     wnd->doc->chunk->format.samplerate,
-				     wnd->doc->chunk->format.samplesize*8);
-
+	  c = g_strdup_printf ( _("mhWaveEdit: %s (%s): %d Hz, %s"),
+				wnd->doc->titlename,
+				chunk_get_time(wnd->doc->chunk,
+					       wnd->doc->chunk->length,
+					       NULL),
+				wnd->doc->chunk->format.samplerate,
+				sampletype_name(&(wnd->doc->chunk->format)));
      } else 
 	  c = g_strdup(PROGRAM_VERSION_STRING);
      gtk_window_set_title ( GTK_WINDOW ( wnd ), c );
@@ -892,7 +879,7 @@ static void edit_redo(GtkMenuItem *menuitem, gpointer user_data)
 
 static void update_clipboard_items(Mainwindow *w, gpointer user_data)
 {
-     set_sensitive(w->need_clipboard_items,(int)user_data);
+     set_sensitive(w->need_clipboard_items,user_data != NULL);
 }
 
 static void edit_cut(GtkMenuItem *menuitem, gpointer user_data)
@@ -911,7 +898,7 @@ static void edit_cut(GtkMenuItem *menuitem, gpointer user_data)
 
      document_update(w->doc, chunk, w->doc->selstart, -(clipboard->length));
      list_object_foreach(mainwindow_objects, (GFunc)update_clipboard_items, 
-			 (gpointer)1);
+			 (gpointer)w);
 }
 
 static void edit_crop(GtkMenuItem *menu_item, gpointer user_data)
@@ -934,7 +921,7 @@ static void edit_copy(GtkMenuItem *menu_item, gpointer user_data)
      gtk_object_sink(GTK_OBJECT(clipboard));
 
      list_object_foreach(mainwindow_objects, (GFunc)update_clipboard_items, 
-			 (gpointer)1);
+			 (gpointer)w);
 }
 
 static void edit_paste(GtkMenuItem *menu_item, gpointer user_data)
@@ -1104,6 +1091,12 @@ static void debug_dummy(GtkMenuItem *menuitem, gpointer user_data)
      document_apply(w->doc,dummy_proc,NULL,CHUNK_FILTER_MANY,FALSE,"DUMMY");
 }
 
+static void debug_dummy2(GtkMenuItem *menuitem, gpointer user_data)
+{
+     Mainwindow *w = MAINWINDOW(user_data);
+     document_apply(w->doc,dummy_proc,NULL,CHUNK_FILTER_MANY,TRUE,"DUMMY");
+}
+
 static void checkoc_proc(Chunk *chunk, gpointer user_data)
 {
      if (chunk->opencount > 0) 
@@ -1255,7 +1248,7 @@ static void effects_mixchannels(GtkMenuItem *menuitem, gpointer user_data)
      }
 }
 
-static void effects_splitchannel(GtkMenuItem *menuitem, gboolean user_data)
+static void effects_splitchannel(GtkMenuItem *menuitem, gpointer user_data)
 {
      Mainwindow *w = MAINWINDOW (user_data);
      Chunk *c;
@@ -1368,7 +1361,7 @@ static void help_readme(GtkMenuItem *menuitem, gpointer user_data)
      gtk_box_pack_start (GTK_BOX (box1), box2, TRUE, TRUE, 0);
      gtk_widget_show (box2);
 
-     table = gtk_table_new (3, 6, FALSE);
+     table = gtk_table_new (4, 6, FALSE);
      gtk_box_pack_start (GTK_BOX (box2), table, TRUE, TRUE, 0);
 
      notebook = gtk_notebook_new ();
@@ -1469,7 +1462,7 @@ gtk_window_set_modal(GTK_WINDOW(a),TRUE);
      gtk_box_pack_start(GTK_BOX(b),c,FALSE,FALSE,0);
      gtk_widget_show(c);
      c = gtk_label_new(_("Created by Magnus Hjorth (magnus.hjorth@home.se)\n"
-	  "Copyright 2002-2007, Magnus Hjorth"));
+	  "Copyright 2002-2012, Magnus Hjorth"));
      gtk_box_pack_start(GTK_BOX(b),c,FALSE,FALSE,0);
      gtk_widget_show(c);
      c = gtk_hseparator_new();
@@ -1588,9 +1581,11 @@ static void view_vertzoom(GtkCheckMenuItem *checkmenuitem, gpointer user_data)
      if (checkmenuitem->active) {
 	  gtk_widget_show(w->vzoom_icon);
 	  gtk_widget_show(w->vzoom_slider);
+	  gtk_widget_show(GTK_WIDGET(w->vzoom_label));
      } else {
 	  gtk_widget_hide(w->vzoom_icon);
 	  gtk_widget_hide(w->vzoom_slider);
+	  gtk_widget_hide(GTK_WIDGET(w->vzoom_label));
      }
 }
 
@@ -1601,7 +1596,7 @@ static void view_speed(GtkCheckMenuItem *checkmenuitem, gpointer user_data)
      if (checkmenuitem->active) {
 	  gtk_widget_show(w->speed_icon);
 	  gtk_widget_show(w->speed_slider);
-	  gtk_widget_show(GTK_WIDGET(w->speed_label));
+	  if (w->show_labels) gtk_widget_show(GTK_WIDGET(w->speed_label));
      } else {
 	  gtk_widget_hide(w->speed_icon);
 	  gtk_widget_hide(w->speed_slider);
@@ -1609,6 +1604,22 @@ static void view_speed(GtkCheckMenuItem *checkmenuitem, gpointer user_data)
      }
 }
 
+static void view_sliderlabels(GtkCheckMenuItem *checkmenuitem, gpointer user_data)
+{
+     Mainwindow *w = MAINWINDOW(user_data);
+     w->show_labels = checkmenuitem->active;
+     if (w->vzoom_slider == NULL) return;
+     if (w->show_labels) {
+	  if (GTK_WIDGET_VISIBLE(w->vzoom_slider))
+	       gtk_widget_show(GTK_WIDGET(w->vzoom_label));
+	  if (GTK_WIDGET_VISIBLE(w->speed_slider))
+	       gtk_widget_show(GTK_WIDGET(w->speed_label));
+     } else {
+	  gtk_widget_hide(GTK_WIDGET(w->vzoom_label));
+	  gtk_widget_hide(GTK_WIDGET(w->speed_label));	  
+     }
+}
+
 static void edit_insertsilence(GtkMenuItem *menuitem, gpointer user_data)
 {
      Mainwindow *w = MAINWINDOW ( user_data );
@@ -1632,7 +1643,7 @@ static void edit_clearclipboard(GtkMenuItem *menuitem, gpointer user_data)
      gtk_object_unref(GTK_OBJECT(clipboard));
      clipboard = NULL;
      list_object_foreach(mainwindow_objects, 
-			 (GFunc)update_clipboard_items, (gpointer)0);
+			 (GFunc)update_clipboard_items, NULL);
 }
 
 static void edit_positioncursor(GtkMenuItem *menuitem, gpointer user_data)
@@ -1911,6 +1922,7 @@ static GtkWidget *create_menu(Mainwindow *w)
 	  { N_("/View/_Horizontal zoom"),NULL,  view_horizoom,  0, "<CheckItem>" },
 	  { N_("/View/_Vertical zoom"),NULL,    view_vertzoom,  0, "<CheckItem>" },
 	  { N_("/View/Sp_eed slider"),NULL,     view_speed,     0, "<CheckItem>" },
+	  { N_("/View/Slider labels"),NULL,     view_sliderlabels,0,"<CheckItem>"},
 	  { N_("/_Cursor"),       NULL,         NULL,           0, "<Branch>"    },
 	  {N_("/Cursor/Set selection start"),"<control>Q",edit_selstartcursor,0,
 	   NULL},
@@ -1974,6 +1986,7 @@ static GtkWidget *create_menu(Mainwindow *w)
 	  { N_("/Debug"),         NULL,         NULL,           0, "<Branch>"    },
 	  /*	  { N_("/Debug/Mark as modified"),NULL, debug_mark,     0, NULL          }, */
 	  { N_("/Debug/Dummy effect"),NULL,     debug_dummy,    0, NULL          },
+	  { N_("/Debug/Dummy effect FP"),NULL,  debug_dummy2,   0, NULL          },
 	  { N_("/Debug/Check opencount"),NULL,  debug_checkoc,  0, NULL          },
 	  { N_("/Debug/Dump chunk info"),NULL,  debug_chunkinfo,0, NULL          },
 #endif
@@ -2101,6 +2114,11 @@ static GtkWidget *create_menu(Mainwindow *w)
 	  (GTK_CHECK_MENU_ITEM(item),
 	   inifile_get_gboolean(INI_SETTING_SPEED,INI_SETTING_SPEED_DEFAULT));
 							  
+     item = gtk_item_factory_get_item(item_factory,"/View/Slider labels");
+     gtk_check_menu_item_set_active
+	  (GTK_CHECK_MENU_ITEM(item),
+	   inifile_get_gboolean(INI_SETTING_SLABELS,INI_SETTING_SLABELS_DEFAULT));
+
      item = gtk_item_factory_get_item(item_factory,"/Play/Record...");
      gtk_widget_set_sensitive(item,input_supported());
 
@@ -2416,7 +2434,7 @@ static void mainwindow_zoom_changed(GtkAdjustment *adjustment,
      max_samp = w->doc->chunk->length;
      target_samp = max_samp * pow(min_samp/max_samp,adjustment->value);
      follow_cursor = target_samp <= current_samp;
-     document_zoom(w->doc,current_samp/target_samp,(target_samp<=current_samp));
+     document_zoom(w->doc,current_samp/target_samp,follow_cursor);
 }
 
 static void mainwindow_vertical_zoom_changed(GtkAdjustment *adjustment,
@@ -2424,8 +2442,18 @@ static void mainwindow_vertical_zoom_changed(GtkAdjustment *adjustment,
 {
      gfloat s;
      Mainwindow *w = MAINWINDOW(user_data);
+     gchar c[32],d[32];
+     int ndec;
      s = pow(100.0, adjustment->value);
      chunk_view_set_scale(w->view, s);
+     ndec = 3-(int)(adjustment->value*2.0);
+     if (ndec > 0) {
+	  g_snprintf(d,sizeof(d),"V: %%.0%df",ndec);
+	  g_snprintf(c,sizeof(c),d,(float) s);
+     } else {
+	  g_snprintf(c,sizeof(c),"V: %d",(int)s);
+     }
+     gtk_label_set_text(w->vzoom_label,c);
 }
 
 static void mainwindow_speed_changed(GtkAdjustment *adjustment,
@@ -2440,7 +2468,7 @@ static void mainwindow_speed_changed(GtkAdjustment *adjustment,
 #endif
      if (w->doc == playing_document)
 	  player_set_speed(f);
-     g_snprintf(c,sizeof(c),"%d%%",(int)(f*100.0+0.5));
+    g_snprintf(c,sizeof(c),"S: %d%%",(int)(f*100.0+0.5));
      gtk_label_set_text(w->speed_label,c);
 }
 
@@ -2523,7 +2551,7 @@ static void mainwindow_init(Mainwindow *obj)
      gtk_signal_connect( GTK_OBJECT(obj->zoom_adj), "value-changed",
 			 GTK_SIGNAL_FUNC(mainwindow_zoom_changed), obj);
      obj->vertical_zoom_adj = 
-	  GTK_ADJUSTMENT(gtk_adjustment_new( 0.0,0.0,1.2,0.01,0.1,0.2) );
+       GTK_ADJUSTMENT(gtk_adjustment_new ( 0, 0, 0.2 + log (inifile_get_guint32 ("vzoomMax", 100)) / log (100.0), 0.01, 0.1, 0.2 ));
      gtk_signal_connect( GTK_OBJECT(obj->vertical_zoom_adj), "value-changed",
 			 GTK_SIGNAL_FUNC(mainwindow_vertical_zoom_changed),
 			 obj);
@@ -2549,10 +2577,14 @@ static void mainwindow_init(Mainwindow *obj)
      obj->vzoom_icon = obj->vzoom_slider = NULL;
      obj->hzoom_icon = obj->hzoom_slider = NULL;
      obj->speed_icon = obj->speed_slider = NULL;
-     obj->speed_label = GTK_LABEL(gtk_label_new("500%"));     
-     gtk_misc_set_alignment(GTK_MISC(obj->speed_label),1.0,0.0);
+     obj->speed_label = GTK_LABEL(gtk_label_new("S: 500%"));
+     gtk_misc_set_alignment(GTK_MISC(obj->speed_label),0.0,0.0);
      gtk_widget_size_request(GTK_WIDGET(obj->speed_label),&req);
      gtk_widget_set_usize(GTK_WIDGET(obj->speed_label),req.width,req.height);
+     obj->vzoom_label = GTK_LABEL(gtk_label_new("V: 1.000"));
+     gtk_misc_set_alignment(GTK_MISC(obj->vzoom_label),0.0,0.0);
+     gtk_widget_size_request(GTK_WIDGET(obj->vzoom_label),&req);
+     gtk_widget_set_usize(GTK_WIDGET(obj->vzoom_label),req.width,req.height);
 
      obj->need_chunk_items = NULL;
      obj->need_selection_items = NULL;
@@ -2610,7 +2642,7 @@ static void mainwindow_init(Mainwindow *obj)
 #endif
      gtk_scale_set_digits(GTK_SCALE(c),3);
      gtk_scale_set_draw_value (GTK_SCALE(c), FALSE);
-     gtk_table_attach(GTK_TABLE(b),c,2,3,1,2,GTK_FILL,GTK_EXPAND|GTK_FILL,0,0);
+     gtk_table_attach(GTK_TABLE(b),c,2,3,1,2,0,GTK_EXPAND|GTK_FILL,0,0);
      obj->need_chunk_items = g_list_append(obj->need_chunk_items,c);
      obj->hzoom_slider = c;
 
@@ -2622,7 +2654,7 @@ static void mainwindow_init(Mainwindow *obj)
 #endif
      gtk_scale_set_digits(GTK_SCALE(c),3);
      gtk_scale_set_draw_value (GTK_SCALE(c), FALSE);
-     gtk_table_attach(GTK_TABLE(b),c,1,2,1,2,GTK_FILL,GTK_EXPAND|GTK_FILL,0,0);
+     gtk_table_attach(GTK_TABLE(b),c,1,2,1,2,0,GTK_EXPAND|GTK_FILL,0,0);
      obj->need_chunk_items = g_list_append(obj->need_chunk_items,c);
      obj->vzoom_slider = c;
 
@@ -2638,7 +2670,7 @@ static void mainwindow_init(Mainwindow *obj)
 #ifndef INV_SPEED
      gtk_range_set_inverted(GTK_RANGE(c),TRUE);
 #endif
-     gtk_table_attach(GTK_TABLE(b),c,3,4,1,2,GTK_FILL,GTK_EXPAND|GTK_FILL,0,0);
+     gtk_table_attach(GTK_TABLE(b),c,3,4,1,2,0,GTK_EXPAND|GTK_FILL,0,0);
      obj->need_chunk_items = g_list_append(obj->need_chunk_items,c);
      obj->speed_slider = c;
 
@@ -2646,15 +2678,23 @@ static void mainwindow_init(Mainwindow *obj)
      gtk_table_attach(GTK_TABLE(b),c,0,1,2,3,GTK_FILL,0,0,0);
 
      c = GTK_WIDGET(obj->speed_label);
-     gtk_table_attach(GTK_TABLE(b),c,1,4,2,3,GTK_FILL,0,0,0);
+     gtk_table_attach(GTK_TABLE(b),c,1,4,3,4,GTK_FILL,0,2,0);
+
+     c = gtk_event_box_new();
+     gtk_container_add(GTK_CONTAINER(c),GTK_WIDGET (obj->statusbar));
+     gtk_table_attach(GTK_TABLE(b),c,0,1,3,4,GTK_FILL,0,0,0);
+
+     c = GTK_WIDGET(obj->vzoom_label);
+     gtk_table_attach(GTK_TABLE(b),c,1,4,2,3,GTK_FILL,0,2,0);
 
-     gtk_box_pack_start(GTK_BOX(a),GTK_WIDGET(obj->statusbar),FALSE,TRUE,0);
      gtk_adjustment_value_changed(obj->speed_adj);
+     gtk_adjustment_value_changed(obj->vertical_zoom_adj);
      gtk_widget_show_all(a);
 
      if (!inifile_get_gboolean(INI_SETTING_VZOOM,INI_SETTING_VZOOM_DEFAULT)) {
 	  gtk_widget_hide(obj->vzoom_icon);
 	  gtk_widget_hide(obj->vzoom_slider);
+	  gtk_widget_hide(GTK_WIDGET(obj->vzoom_label));
      }
 
      if (!inifile_get_gboolean(INI_SETTING_HZOOM,INI_SETTING_HZOOM_DEFAULT)) {
@@ -2668,6 +2708,12 @@ static void mainwindow_init(Mainwindow *obj)
 	  gtk_widget_hide(GTK_WIDGET(obj->speed_label));
      }
 
+     obj->show_labels = inifile_get_gboolean(INI_SETTING_SLABELS,INI_SETTING_SLABELS_DEFAULT);
+     if (!obj->show_labels) {
+	  gtk_widget_hide(GTK_WIDGET(obj->vzoom_label));
+	  gtk_widget_hide(GTK_WIDGET(obj->speed_label));
+     }
+
      gtk_window_set_policy(GTK_WINDOW(obj),FALSE,TRUE,FALSE);
      
      set_sensitive(obj->need_chunk_items, FALSE);
