@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 2005, Magnus Hjorth
+ * Copyright (C) 2004 2005 2008 2009, Magnus Hjorth
  *
  * This file is part of mhWaveEdit.
  *
@@ -260,7 +260,7 @@ static gboolean process_input(RecordDialog *rd)
      }
      convert_array(rd->analysis_buf,rd->current_format,
 		   rd->analysis_sbuf,&dataformat_sample_t,
-		   rd->analysis_samples, DITHER_NONE);
+		   rd->analysis_samples, DITHER_NONE, NULL);
      /* Calculate statistics */
      sq = &(rd->analysis_sbuf[rd->analysis_samples]);
      d = rd->current_format->channels;
@@ -320,7 +320,7 @@ static gboolean process_input(RecordDialog *rd)
 		   0,buf,default_time_mode);
 	  gtk_label_set_text(rd->time_label,buf);
 	  g_snprintf(buf,200,"%" OFF_T_FORMAT "", 
-		     rd->written_bytes);
+		     (OFF_T_FTYPE)rd->written_bytes);
 	  gtk_label_set_text(rd->bytes_label,buf);
 	  get_time_s(rd->current_format->samplerate,
 		     rd->written_bytes/rd->current_format->samplebytes,
