@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 2005, Magnus Hjorth
+ * Copyright (C) 2004 2005 2006 2008 2009 2011 2012, Magnus Hjorth
  *
  * This file is part of mhWaveEdit.
  *
@@ -21,12 +21,6 @@
 
 /* JACK sound driver */
 
-/* Currently, this driver has some limitations: 
- *   - Output is always in the (-1.0,1.0) range.
- *   - Input is expected to be normalized so absolute values > 1.0 will be
- *     clipped.
- */
-
 #include <jack/jack.h>
 #include <jack/ringbuffer.h>
 
@@ -520,7 +514,8 @@ static gint mhjack_output_select_format(Dataformat *format, gboolean silent,
      if (!mhjack.is_activated) return silent ? -1 : +1;
 
      if (format->type != DATAFORMAT_FLOAT ||
-	 format->samplesize != sizeof(float))
+	 format->samplesize != sizeof(float) ||
+	 XOR(format->bigendian,ieee_be_compatible))
 	  return -1;
 
      if (format->samplerate != jack_get_sample_rate(mhjack.myself)) return -1;
@@ -546,6 +541,7 @@ static gboolean mhjack_output_suggest_format(Dataformat *format,
      memcpy(result,format,sizeof(Dataformat));
      result->type = DATAFORMAT_FLOAT;
      result->samplesize = sizeof(float);
+     result->bigendian = ieee_be_compatible;
      result->samplebytes = result->samplesize * result->channels;
      result->samplerate = jack_get_sample_rate(mhjack.myself);
      return TRUE;
@@ -580,7 +576,7 @@ static guint mhjack_output_play(gchar *buffer, guint bufsize)
      
      /* Convert data to floats */
      convert_array(buffer,&(mhjack.current_format),fbuf,&dataformat_single,
-		   frames*mhjack.current_format.channels,DITHER_NONE);
+		   frames*mhjack.current_format.channels,DITHER_NONE,NULL);
 
      /* De-interleave and write data to the different ring buffers. */
 
@@ -688,7 +684,7 @@ static void mhjack_input_store(Ringbuf *buffer)
      /* Convert data (in case sample_t == double, otherwise, convert_array
       * just does a memcpy). Dithering never matters in this conversion. */
      convert_array(fbuf2,&dataformat_single,sbuf,&(mhjack.current_format),
-		   frames*mhjack.current_format.channels,DITHER_NONE);
+		   frames*mhjack.current_format.channels,DITHER_NONE,NULL);
      /* Add to ring buffer */
      s = ringbuf_enqueue(buffer,sbuf,frames*mhjack.current_format.samplebytes);
      g_assert(s == frames*mhjack.current_format.samplebytes);
