@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008, Magnus Hjorth
+ * Copyright (C) 2008 2009 2011 2012, Magnus Hjorth
  *
  * This file is part of mhWaveEdit.
  *
@@ -396,6 +396,7 @@ static struct {
      gboolean recursing_mainloop;
      gpointer ready_constsource;
      GVoidFunc ready_func;
+     gboolean stopping;
 } pulse_data = { 0 };
 
 static void pulse_context_state_cb(pa_context *c, void *userdata)
@@ -466,25 +467,30 @@ static gboolean format_to_pulse(Dataformat *format, pa_sample_spec *ss_out)
      pa_sample_format_t sf;
 
      if (format->type == DATAFORMAT_PCM) {
-	  if (format->samplesize == 1 && format->sign == FALSE)
+	  if (format->samplesize == 1 && !format->sign)
 	       sf = PA_SAMPLE_U8;
-	  else if (format->samplesize == 2 && format->sign == TRUE)
+	  else if (format->samplesize == 2 && format->sign)
 	       sf = (format->bigendian)?PA_SAMPLE_S16BE:PA_SAMPLE_S16LE;
 #ifdef HAS24
-	  else if (format->samplesize == 3 && format->sign == TRUE)
+	  else if (format->samplesize == 3 && format->sign)
 	       sf = (format->bigendian)?PA_SAMPLE_S24BE:PA_SAMPLE_S24LE;
 #endif
-	  else if (format->samplesize == 4 && format->sign == TRUE)
-	       sf = (format->bigendian)?PA_SAMPLE_S32BE:PA_SAMPLE_S32LE;
-	  else
+	  else if (format->samplesize == 4 && format->sign) {
+	       if (format->packing == 0 || format->packing == 1)
+		    sf = (format->bigendian)?PA_SAMPLE_S32BE:PA_SAMPLE_S32LE;
+#ifdef HAS24
+	       else
+		    sf = (format->bigendian)?PA_SAMPLE_S24_32LE:PA_SAMPLE_S24_32BE;
+#endif
+	  } else
 	       return TRUE;
      } else if (format->type == DATAFORMAT_FLOAT && format->samplesize == 4) {
-	  if (ieee_le_compatible)
-	       sf = PA_SAMPLE_FLOAT32LE;
-	  else if (ieee_be_compatible)
+	  if (!ieee_le_compatible && !ieee_be_compatible)
+	       return TRUE;
+	  else if (format->bigendian)
 	       sf = PA_SAMPLE_FLOAT32BE;
 	  else
-	       return TRUE;
+	       sf = PA_SAMPLE_FLOAT32LE;
      } else 
 	  return TRUE;
 
@@ -512,15 +518,19 @@ static gboolean pa_format_from_pulse(pa_sample_spec *ss, Dataformat *format_out)
      case PA_SAMPLE_S32LE:
      case PA_SAMPLE_S32BE:
 	  f.type = DATAFORMAT_PCM;
+	  f.packing = 0;
 	  if (i == PA_SAMPLE_U8) 
 	       f.samplesize = 1;
-	  else if (i == PA_SAMPLE_S16LE || i == PA_SAMPLE_S16BE) 
+	  else if (i == PA_SAMPLE_S16LE || i == PA_SAMPLE_S16BE) {
 	       f.samplesize = 2;
 #ifdef HAS24
-	  else if (i == PA_SAMPLE_S24LE || i == PA_SAMPLE_S24BE)
+	  } else if (i == PA_SAMPLE_S24LE || i == PA_SAMPLE_S24BE)
 	       f.samplesize = 3;
+	  else if (i == PA_SAMPLE_S24_32LE || i == PA_SAMPLE_S24_32LE) {
+	       f.samplesize = 4;
+	       f.packing = 2;
 #endif
-	  else
+	  } else
 	       f.samplesize = 4;
 	  f.sign = !(i == PA_SAMPLE_U8);
 	  if (i == PA_SAMPLE_S16BE || i == PA_SAMPLE_S32BE
@@ -533,14 +543,16 @@ static gboolean pa_format_from_pulse(pa_sample_spec *ss, Dataformat *format_out)
 	       f.bigendian = FALSE;	  
 	  break;
      case PA_SAMPLE_FLOAT32LE:
-	  if (!ieee_le_compatible) return TRUE;
+	  if (!ieee_le_compatible && !ieee_be_compatible) return TRUE;
 	  f.type = DATAFORMAT_FLOAT;
 	  f.samplesize = 4;
+	  f.bigendian = FALSE;
 	  break;
      case PA_SAMPLE_FLOAT32BE:
-	  if (!ieee_be_compatible) return TRUE;
+	  if (!ieee_le_compatible && !ieee_be_compatible) return TRUE;
 	  f.type = DATAFORMAT_FLOAT;
 	  f.samplesize = 4;
+	  f.bigendian = TRUE;
 	  break;
      default:
 	  return TRUE;
@@ -642,7 +654,8 @@ static int ready_constsource_cb(gpointer csource, gpointer user_data)
 
 static void pulse_ready_func(pa_stream *p, size_t bytes, void *userdata)
 {
-     mainloop_constant_source_enable(pulse_data.ready_constsource, TRUE);
+     if (!pulse_data.stopping)
+          mainloop_constant_source_enable(pulse_data.ready_constsource, TRUE);
 }
 
 static void ready_constsource_setup(void)
@@ -752,6 +765,7 @@ static gboolean pulse_output_stop(gboolean must_flush)
      /* puts("pulse_output_stop"); */
      if (pulse_data.ready_constsource != NULL)
 	  mainloop_constant_source_enable(pulse_data.ready_constsource,FALSE);
+     pulse_data.stopping = 1;
 
      if (pulse_data.stream != NULL) {
 	  if (must_flush || pulse_flush_in_progress()) {
@@ -772,6 +786,7 @@ static gboolean pulse_output_stop(gboolean must_flush)
 	  pulse_data.recursing_mainloop = FALSE;
 
      }
+     pulse_data.stopping = 0;
      return FALSE;
 }
 
